@@ -49,15 +49,18 @@ use constant {
     WARN            => 'warn',              # default warning handler
     BLANK           => '',                  # how much more blank could this be?
     SPACE           => ' ',                 # and the answer is none, none more blank
+    SLASH           => '/',                 # URI path delimiter
     DELIMITER       => qr/(?:,\s*)|\s+/,    # match a comma or whitespace
     WILDCARD        => qr/[\*\?]/,          # wildcards: *.html foo??.txt
     LOADED          => 'BADGER_LOADED',     # set by Badger::Class on autoload
-
+    UTF8            => 'utf8',
+    YAML            => 'yaml',
+    JSON            => 'json',
 };
 
 CONSTANTS->export_any(qw( 
-    CONSTANTS FIRST LAST CRLF PKG DOT REFS ONCE WARN BLANK SPACE 
-    DELIMITER WILDCARD LOADED
+    CONSTANTS FIRST LAST CRLF PKG DOT REFS ONCE WARN BLANK SPACE SLASH
+    DELIMITER WILDCARD LOADED UTF8 YAML JSON
 ));
 
 CONSTANTS->export_tags({
@@ -232,6 +235,11 @@ none.  None more blank.
 A single space character. Not to be confused with the three dimensional fabric
 of reality that it happens to share a name with.
 
+=head2 SLASH
+
+A forward slash as used to separate path segments in URIs and filesystem paths
+on sane operating systems.
+
 =head2 DELIMITER
 
 A regular expression used to split whitespace delimited tokens.  Also
@@ -249,6 +257,18 @@ wildcard characters.
         # do someting...
     } 
 
+=head2 UTF8
+
+The literal string C<utf8>.
+
+=head2 JSON
+
+The literal string C<json>.
+
+=head2 YAML
+
+The literal string C<yaml>.
+
 =head2 LOADED
 
 Contains the literal string C<BADGER_LOADED>.  The L<Badger::Class> module
